==> libreoffice-still-sdk-7.1.8-1-aarch64.pkg.tar.xz: usr/share/doc/libreoffice/sdk/docs/idl/ref/search/enumvalues_e.js <==
var searchData=
[
  ['objectspecific_0',['OBJECTSPECIFIC',['../namespacecom_1_1sun_1_1star_1_1drawing.html#ae1e109a5c70543e3b92db3b854fd3acba3668dde04e6e254e9823521932670f83',1,'com::sun::star::drawing']]],
  ['oblique_1',['OBLIQUE',['../namespacecom_1_1sun_1_1star_1_1awt.html#a362a86d3ebca4a201d13bc3e7b94340ea5f8acbea11254d9a8f0fb40f9ede92bd',1,'com::sun::star::awt']]],
  ['obtainedvalue_2',['ObtainedValue',['../namespacecom_1_1sun_1_1star_1_1inspection.html#a2c7cbb6dbe76b989188c75ba8e400876ab05b93088e4ac5796c3ceb57f3334ec8',1,'com::sun::star::inspection']]],
  ['ok_3',['OK',['../namespacecom_1_1sun_1_1star_1_1awt.html#aa4e49c7e6c5bf2b4d010ad4a50b90ec0a2bc49ec37d6a5715dd23e85f1ff5bb59',1,'com::sun::star::awt::OK()'],['../namespacecom_1_1sun_1_1star_1_1script.html#a8ab52fac6ca48179fe55e9a6aa3a345da2bc49ec37d6a5715dd23e85f1ff5bb59',1,'com::sun::star::script::OK()']]],
  ['once_4',['ONCE',['../namespacecom_1_1sun_1_1star_1_1ucb.html#ae0c1e5cfd30d96e351c556663af5638baf1110c378b0b40a4b5bd04fdd92220c4',1,'com::sun::star::ucb']]],
  ['one_5',['ONE',['../namespacecom_1_1sun_1_1star_1_1ucb.html#a01e925906d2f84e461036af17439e9caa7a725f13af144bdef532d0389ba75e0d',1,'com::sun::star::ucb::ONE()'],['../namespacecom_1_1sun_1_1star_1_1reflection.html#a19627c9e2873087a7d672cd9e0913000a7a725f13af144bdef532d0389ba75e0d',1,'com::sun::star::reflection::ONE()']]],
  ['one_5flevel_6',['ONE_LEVEL',['../namespacecom_1_1sun_1_1star_1_1ucb.html#a8f357eda7c29e9601428bdc8834c7bd8af903fa02276fd31c3c41b458fa3a95b5',1,'com::sun::star::ucb']]],
  ['oneway_7',['ONEWAY',['../namespacecom_1_1sun_1_1star_1_1reflection.html#a5e114fee85d0f2f8cb01480a474dd9b4a232395325c4df6853ee3dd7ac761006a',1,'com::sun::star::reflection']]],
  ['only_8',['ONLY',['../namespacecom_1_1sun_1_1star_1_1text.html#a95d9f731f1389ee9f277e756b476251ca620503848b4e75d10e3e198fb77a656b',1,'com::sun::star::text']]],
  ['open_5fhorizontal_9',['OPEN_HORIZONTAL',['../namespacecom_1_1sun_1_1star_1_1presentation.html#a9db0b8c5e72e0ae290ff76da0dd53e3da829921ab4e8f50f9147c032d76e1b851',1,'com::sun::star::presentation']]],
  ['open_5fvertical_10',['OPEN_VERTICAL',['../namespacecom_1_1sun_1_1star_1_1presentation.html#a9db0b8c5e72e0ae290ff76da0dd53e3da17833ba6a185c96bfec21f6ec6787fb4',1,'com::sun::star::presentation']]],
  ['openpgp_11',['OPENPGP',['../namespacecom_1_1sun_1_1star_1_1security.html#a15fb2a8475364a68c176c7789e3611cca3a692361863c676b710fb98611e0ddc2',1,'com::sun::star::security']]],
  ['operation_5fsucceeded_12',['OPERATION_SUCCEEDED',['../namespacecom_1_1sun_1_1star_1_1xml_1_1crypto.html#ab5d887eb5da1173b766d96d0d863d1dca22daebf9c43b1cff1f171fe794ae0825',1,'com::sun::star::xml::crypto']]],
  ['options_13',['OPTIONS',['../namespacecom_1_1sun_1_1star_1_1ucb.html#a3c143367536e0c519b25183505ae3ed7a1b20f1b4adb6ff9778b284fb46f6f99d',1,'com::sun::star::ucb']]],
  ['or_14',['OR',['../namespacecom_1_1sun_1_1star_1_1sheet.html#a946b76fb59cd525a1296ff815333d110a96727447c0ad447987df1c6415aef074',1,'com::sun::star::sheet']]],
  ['original_15',['ORIGINAL',['../namespacecom_1_1sun_1_1star_1_1media.html#aa2569917c2883c1d1c0c0ee02e671ac6ac68af7f5fa830636c92ff457b408f59d',1,'com::sun::star::media']]],
  ['other_5fname_16',['OTHER_NAME',['../namespacecom_1_1sun_1_1star_1_1security.html#a5c5a31742567126d2ba88393b05efa3fa95f10716c12a070e616aedcf28302f4a',1,'com::sun::star::security']]],
  ['other_5fneutral_17',['OTHER_NEUTRAL',['../namespacecom_1_1sun_1_1star_1_1i18n.html#a6e8fd3df14c13e43a44061c70daacd8bafd4865ee771b0491db7a347a128deb9c',1,'com::sun::star::i18n']]],
  ['out_18',['OUT',['../namespacecom_1_1sun_1_1star_1_1reflection.html#ada880a15fc14bc0e53c3dd7c3c8a34ebac72cb4ba9e379a25e80f157177dbe2b8',1,'com::sun::star::reflection']]],
  ['out_5fof_5fdisk_5fspace_19',['OUT_OF_DISK_SPACE',['../namespacecom_1_1sun_1_1star_1_1ucb.html#ab0378c2985abaca86838ed9936c3a2d5a983d70d9d729565ac5a01a38f6864521',1,'com::sun::star::ucb']]],
  ['out_5fof_5ffile_5fhandles_20',['OUT_OF_FILE_HANDLES',['../namespacecom_1_1sun_1_1star_1_1ucb.html#ab0378c2985abaca86838ed9936c3a2d5ad41dea74c08f5726378de6adbd685040',1,'com::sun::star::ucb']]],
  ['out_5fof_5fmemory_21',['OUT_OF_MEMORY',['../namespacecom_1_1sun_1_1star_1_1ucb.html#ab0378c2985abaca86838ed9936c3a2d5ac9a7e95f8dd5507c2dbd1fb466ec9a85',1,'com::sun::star::ucb']]],
  ['outer_5fborder_22',['OUTER_BORDER',['../namespacecom_1_1sun_1_1star_1_1drawing_1_1framework.html#a62ba43b838957db08d5ecb9b46b8ca90a843846c63c0e6c20a4297938cc221f4c',1,'com::sun::star::drawing::framework']]],
  ['outside_5fend_23',['OUTSIDE_END',['../namespacecom_1_1sun_1_1star_1_1chart.html#a693b6b549818a6055effeaf72501bd26aaf5a00e50947042fd4cc832d9db5a8f3',1,'com::sun::star::chart']]],
  ['outside_5fstart_24',['OUTSIDE_START',['../namespacecom_1_1sun_1_1star_1_1chart.html#a693b6b549818a6055effeaf72501bd26a6afe225d6097e3367072d35eb601c421',1,'com::sun::star::chart']]],
  ['overpaint_25',['OVERPAINT',['../namespacecom_1_1sun_1_1star_1_1awt.html#a54da390665a5b42acc81143cd24926fdabe19a59af529f491ebb33144917b6ae9',1,'com::sun::star::awt']]]
];

==> libreoffice-still-sdk-7.4.5-1-aarch64.pkg.tar.xz: usr/share/doc/libreoffice/sdk/docs/idl/ref/search/enumvalues_e.js <==
var searchData=
[
  ['objectspecific_0',['OBJECTSPECIFIC',['../namespacecom_1_1sun_1_1star_1_1drawing.html#ae1e109a5c70543e3b92db3b854fd3acba3668dde04e6e254e9823521932670f83',1,'com::sun::star::drawing']]],
  ['oblique_1',['OBLIQUE',['../namespacecom_1_1sun_1_1star_1_1awt.html#a362a86d3ebca4a201d13bc3e7b94340ea5f8acbea11254d9a8f0fb40f9ede92bd',1,'com::sun::star::awt']]],
  ['obtainedvalue_2',['ObtainedValue',['../namespacecom_1_1sun_1_1star_1_1inspection.html#a2c7cbb6dbe76b989188c75ba8e400876ab05b93088e4ac5796c3ceb57f3334ec8',1,'com::sun::star::inspection']]],
  ['ok_3',['OK',['../namespacecom_1_1sun_1_1star_1_1script.html#a8ab52fac6ca48179fe55e9a6aa3a345da2bc49ec37d6a5715dd23e85f1ff5bb59',1,'com::sun::star::script::OK()'],['../namespacecom_1_1sun_1_1star_1_1awt.html#aa4e49c7e6c5bf2b4d010ad4a50b90ec0a2bc49ec37d6a5715dd23e85f1ff5bb59',1,'com::sun::star::awt::OK()']]],
  ['once_4',['ONCE',['../namespacecom_1_1sun_1_1star_1_1ucb.html#ae0c1e5cfd30d96e351c556663af5638baf1110c378b0b40a4b5bd04fdd92220c4',1,'com::sun::star::ucb']]],
  ['one_5',['ONE',['../namespacecom_1_1sun_1_1star_1_1reflection.html#a19627c9e2873087a7d672cd9e0913000a7a725f13af144bdef532d0389ba75e0d',1,'com::sun::star::reflection::ONE()'],['../namespacecom_1_1sun_1_1star_1_1ucb.html#a01e925906d2f84e461036af17439e9caa7a725f13af144bdef532d0389ba75e0d',1,'com::sun::star::ucb::ONE()']]],
  ['one_5flevel_6',['ONE_LEVEL',['../namespacecom_1_1sun_1_1star_1_1ucb.html#a8f357eda7c29e9601428bdc8834c7bd8af903fa02276fd31c3c41b458fa3a95b5',1,'com::sun::star::ucb']]],
  ['oneway_7',['ONEWAY',['../namespacecom_1_1sun_1_1star_1_1reflection.html#a5e114fee85d0f2f8cb01480a474dd9b4a232395325c4df6853ee3dd7ac761006a',1,'com::sun::star::reflection']]],
  ['only_8',['ONLY',['../namespacecom_1_1sun_1_1star_1_1text.html#a95d9f731f1389ee9f277e756b476251ca620503848b4e75d10e3e198fb77a656b',1,'com::sun::star::text']]],
  ['open_5fhorizontal_9',['OPEN_HORIZONTAL',['../namespacecom_1_1sun_1_1star_1_1presentation.html#a9db0b8c5e72e0ae290ff76da0dd53e3da829921ab4e8f50f9147c032d76e1b851',1,'com::sun::star::presentation']]],
  ['open_5fvertical_10',['OPEN_VERTICAL',['../namespacecom_1_1sun_1_1star_1_1presentation.html#a9db0b8c5e72e0ae290ff76da0dd53e3da17833ba6a185c96bfec21f6ec6787fb4',1,'com::sun::star::presentation']]],
  ['openpgp_11',['OPENPGP',['../namespacecom_1_1sun_1_1star_1_1security.html#a15fb2a8475364a68c176c7789e3611cca3a692361863c676b710fb98611e0ddc2',1,'com::sun::star::security']]],
  ['operation_5fsucceeded_12',['OPERATION_SUCCEEDED',['../namespacecom_1_1sun_1_1star_1_1xml_1_1crypto.html#ab5d887eb5da1173b766d96d0d863d1dca22daebf9c43b1cff1f171fe794ae0825',1,'com::sun::star::xml::crypto']]],
  ['options_13',['OPTIONS',['../namespacecom_1_1sun_1_1star_1_1ucb.html#a3c143367536e0c519b25183505ae3ed7a1b20f1b4adb6ff9778b284fb46f6f99d',1,'com::sun::star::ucb']]],
  ['or_14',['OR',['../namespacecom_1_1sun_1_1star_1_1sheet.html#a946b76fb59cd525a1296ff815333d110a96727447c0ad447987df1c6415aef074',1,'com::sun::star::sheet']]],
  ['original_15',['ORIGINAL',['../namespacecom_1_1sun_1_1star_1_1media.html#aa2569917c2883c1d1c0c0ee02e671ac6ac68af7f5fa830636c92ff457b408f59d',1,'com::sun::star::media']]],
  ['other_5fname_16',['OTHER_NAME',['../namespacecom_1_1sun_1_1star_1_1security.html#a5c5a31742567126d2ba88393b05efa3fa95f10716c12a070e616aedcf28302f4a',1,'com::sun::star::security']]],
  ['other_5fneutral_17',['OTHER_NEUTRAL',['../namespacecom_1_1sun_1_1star_1_1i18n.html#a6e8fd3df14c13e43a44061c70daacd8bafd4865ee771b0491db7a347a128deb9c',1,'com::sun::star::i18n']]],
  ['out_18',['OUT',['../namespacecom_1_1sun_1_1star_1_1reflection.html#ada880a15fc14bc0e53c3dd7c3c8a34ebac72cb4ba9e379a25e80f157177dbe2b8',1,'com::sun::star::reflection']]],
  ['out_5fof_5fdisk_5fspace_19',['OUT_OF_DISK_SPACE',['../namespacecom_1_1sun_1_1star_1_1ucb.html#ab0378c2985abaca86838ed9936c3a2d5a983d70d9d729565ac5a01a38f6864521',1,'com::sun::star::ucb']]],
  ['out_5fof_5ffile_5fhandles_20',['OUT_OF_FILE_HANDLES',['../namespacecom_1_1sun_1_1star_1_1ucb.html#ab0378c2985abaca86838ed9936c3a2d5ad41dea74c08f5726378de6adbd685040',1,'com::sun::star::ucb']]],
  ['out_5fof_5fmemory_21',['OUT_OF_MEMORY',['../namespacecom_1_1sun_1_1star_1_1ucb.html#ab0378c2985abaca86838ed9936c3a2d5ac9a7e95f8dd5507c2dbd1fb466ec9a85',1,'com::sun::star::ucb']]],
  ['outer_5fborder_22',['OUTER_BORDER',['../namespacecom_1_1sun_1_1star_1_1drawing_1_1framework.html#a62ba43b838957db08d5ecb9b46b8ca90a843846c63c0e6c20a4297938cc221f4c',1,'com::sun::star::drawing::framework']]],
  ['outside_5fend_23',['OUTSIDE_END',['../namespacecom_1_1sun_1_1star_1_1chart.html#a693b6b549818a6055effeaf72501bd26aaf5a00e50947042fd4cc832d9db5a8f3',1,'com::sun::star::chart']]],
  ['outside_5fstart_24',['OUTSIDE_START',['../namespacecom_1_1sun_1_1star_1_1chart.html#a693b6b549818a6055effeaf72501bd26a6afe225d6097e3367072d35eb601c421',1,'com::sun::star::chart']]],
  ['overpaint_25',['OVERPAINT',['../namespacecom_1_1sun_1_1star_1_1awt.html#a54da390665a5b42acc81143cd24926fdabe19a59af529f491ebb33144917b6ae9',1,'com::sun::star::awt']]]
];
